#//-----------------------------------------------
#//TUSB-S01SWx用ドライバアクセス用API
#//Python 用モジュール
#//
#//2024_03_18　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

from ctypes import *

#デバイス用DLLのロード  
tusbs01swdll = cdll.LoadLibrary("TUSBSSW.DLL")

#デバイスドライバ関数の型定義  (これは直接呼ばない)
tusbs01swdll.Tusbs01sw_Device_Open.restype = c_short
tusbs01swdll.Tusbs01sw_Device_Open.argtypes = (c_short,)
tusbs01swdll.Tusbs01sw_Device_Close.restype = None
tusbs01swdll.Tusbs01sw_Device_Close.argtypes = (c_short,)
tusbs01swdll.Tusbs01sw_Out.restypes = c_short
tusbs01swdll.Tusbs01sw_Out.argtypes = (c_short,c_ubyte)
tusbs01swdll.Tusbs01sw_In.restypes = c_short
tusbs01swdll.Tusbs01sw_In.argtypes = (c_short,POINTER(c_ubyte))

#######  補助関数 (これも呼ばない)
def isint(n):
    return type(n) is int

def IsInRange(Val,Min,Max):
    if(isint(Val) == False ):
        return False
    elif(Val < Min):
        return False
    elif(Val > Max):
        return False
    else:
        return True
    
def IsValidId(DevId):
    return IsInRange(DevId,0,15)

def IsValidOnOff(OnOff):
    return IsInRange(OnOff,0,1)

######　機能関数の定義 
######  以下の関数を呼び出してデバイスを操作する
#DevIdは装置の設定ID
    
# デバイスオープン
def Tusbs01sw_Device_Open(DevId):
    if( IsValidId(DevId) ):
        return tusbs01swdll.Tusbs01sw_Device_Open(DevId)
    else:
        return 8    #Invalid parameter

#デバイスクローズ
def Tusbs01sw_Device_Close(DevId):
    if( IsValidId(DevId) ):
        tusbs01swdll.Tusbs01sw_Device_Close(DevId)
    else:
        return 8    #Invalid parameter

#出力操作
# OnOff : 0->off 1->on
def Tusbs01sw_Out(DevId,OnOff):
    if( IsValidId(DevId) ):
        if(IsValidOnOff(OnOff) ):
            return tusbs01swdll.Tusbs01sw_Out(DevId,OnOff)
    return 8    #Invalid parameter

#出力状態の確認
#タプルを返す(戻り値コード、OnOff状態)
# OnOffは0の時Offで1の時On
def Tusbs01sw_In(DevId):
    tmp = c_ubyte()
    if( IsValidId(DevId) ):
        ret = tusbs01swdll.Tusbs01sw_In(DevId,byref(tmp))
        if( ret != 0 ):
            return ret,0
        else:
            return 0,tmp.value
    else:
        return 8,0    #Invalid parameter

#戻り値用エラーメッセージ
ErrStrDic = {
            0:"正常終了しました",
            1:"ID番号が不正です",
            2:"ドライバがインストールされていません",
            3:"すでにデバイスはオープンされています",
            4:"接続されている台数が多すぎます",
            5:"オープンできませんでした",
            6:"デバイスがみつかりません",
            7:"オープンされていません",
            8:"パラメータエラー",
            9:"USB通信エラーです"
}
def GetErrMessage(retcode):
    if( retcode in ErrStrDic):
        return ErrStrDic[retcode]
    else:
        return "不明なエラーです"